@@ -22,6 +22,8 @@ pub mod layer;
 pub mod utils;
 mod ws;
 
+#[doc(inline)]
+pub use axum_server::HttpConfig;
 /// A boxed HTTP body. This is used to unify response bodies.
 pub type BoxBody = http_body::combinators::BoxBody<Bytes, BoxError>;
 /// A HTTP request.
@@ -44,6 +46,7 @@ pub struct Hyper<L> {
     addr: SocketAddr,
     layer: L,
     tls: Option<(PathBuf, PathBuf)>,
+    config: HttpConfig,
 }
 
 impl Hyper<Identity> {
@@ -55,17 +58,19 @@ impl Hyper<Identity> {
             })?,
             layer: Identity::new(),
             tls: None,
+            config: HttpConfig::new(),
         })
     }
 }
 
 impl<L> Hyper<L> {
-    /// Layer this `hyper` server with a [`Layer`].
+    /// Layer this [`hyper`] server with a [`Layer`].
     pub fn layer<Layer>(self, layer: Layer) -> Hyper<Stack<Layer, L>> {
         Hyper {
             addr: self.addr,
             layer: Stack::new(layer, self.layer),
             tls: self.tls,
+            config: self.config,
         }
     }
 
@@ -79,6 +84,12 @@ impl<L> Hyper<L> {
         self.tls = Some((cert_path.into(), key_path.into()));
         self
     }
+
+    /// Set new configuration for the [`hyper`] HTTP server.
+    pub fn configure_hyper(mut self, config: HttpConfig) -> Self {
+        self.config = config;
+        self
+    }
 }
 
 impl<L, S> Transport for Hyper<L>
@@ -101,11 +112,16 @@ where
                     axum_server::tls_rustls::RustlsConfig::from_pem_file(cert_path, key_path)
                         .await?;
                 axum_server::bind_rustls(self.addr, rustls_conf)
+                    .http_config(self.config)
                     .serve(service)
                     .await
             })
         } else {
-            Box::pin(axum_server::bind(self.addr).serve(service))
+            Box::pin(
+                axum_server::bind(self.addr)
+                    .http_config(self.config)
+                    .serve(service),
+            )
         }
     }
 }
